/*
  Copyright (c) 2016, Antonio SJ Musumeci <trapexit@spawn.link>

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#pragma once

#include "fuse.h"

#include "fs_path.hpp"

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>


namespace FUSE
{
  int
  getattr(const fuse_req_ctx_t *ctx,
          const char           *fusepath,
          struct stat          *buf,
          fuse_timeouts_t      *timeout);

  int
  getattr(const fuse_req_ctx_t *ctx,
          const fs::path       &fusepath,
          struct stat          *buf,
          fuse_timeouts_t      *timeout);

  int
  getattr(const fs::path  &fusepath,
          struct stat     *buf,
          fuse_timeouts_t *timeout);

}
